@@ -38,6 +38,7 @@ class DuplicityCommands:
     NOTE: cli_util must contain a function named check_* for each positional arg,
           for example check_source_path() to check for source path validity.
     """
+    backup = ["source_path", "target_url"]
     cleanup = ["target_url"]
     collection_status = ["target_url"]
     full = ["source_path", "target_url"]
@@ -55,10 +56,11 @@ class CommandAliases:
     """
     commands and aliases
     """
+    backup = ["bu"]
     cleanup = ["cl"]
     collection_status = ["st"]
     full = ["fb"]
-    incremental = ["inc", "ib"]
+    incremental = ["incr", "inc", "ib"]
     list_current_files = ["ls"]
     remove_older_than = ["ro"]
     remove_all_but_n_full = ["ra"]
@@ -93,7 +95,7 @@ class OptionKwargs:
         "default": dflt(config.archive_dir)
     }
     asynchronous_upload = {
-        "action": "store_const",
+        "action": WarnAsyncStoreConstAction,
         "const": 1,
         "dest": "async_concurrency",
         "help": "Number of async upload tasks, max of 1",
@@ -255,6 +257,12 @@ class OptionKwargs:
         "help": "String prefix for duplicity signature files",
         "default": dflt(config.file_prefix_signature)
     }
+    file_prefix_jsonstat = {
+        "metavar": "string",
+        "type": make_bytes,
+        "help": "String prefix for duplicity jsonstat files",
+        "default": dflt(config.file_prefix_jsonstat)
+    }
     files_from = {
         "metavar": _("filename"),
         "type": check_file,
@@ -380,6 +388,13 @@ class OptionKwargs:
         "help": "Include based on regex pattern",
         "default": dflt(None)
     }
+    jsonstat = {
+        "action": "store_true",
+        "help": "if set, an extra file with statistices in json format will bestored with each backup. "
+        "it includes the staistics printed out on stdout by default. "
+        "With 'collection-status' it returs these stats.",
+        "default": dflt(config.jsonstat)
+    }
     log_fd = {
         "metavar": _("file_descriptor"),
         "type": set_log_fd,
@@ -634,6 +649,11 @@ class OptionKwargs:
         "help": "Sign key for encryption/decryption",
         "default": dflt(None)
     }
+    skip_if_no_change = {
+        "action": "store_true",
+        "help": "Skip incremental backup if nothing changed.",
+        "default": dflt(config.skip_if_no_change)
+    }
     ssh_askpass = {
         "action": "store_true",
         "help": "Ask the user for the SSH password. Not for batch usage",
@@ -773,6 +793,11 @@ class CommandOptions:
     """
     legal options by command
     """
+    backup = list(
+        all_options
+        - parent_only_options
+        - deprecated_backup_options
+    )
     cleanup = list(
         all_options
         - parent_only_options
